@@ -7,14 +7,11 @@ use cargo_c::cli::run_cargo_fallback;
 use cargo_c::cli::subcommand_build;
 use cargo_c::config::*;
 
-use clap::*;
-
 fn main() -> CliResult {
     let mut config = Config::default()?;
 
     let subcommand = subcommand_build("cbuild", "Build the crate C-API");
     let mut app = clap::command!()
-        .setting(AppSettings::DeriveDisplayOrder)
         .dont_collapse_args_in_usage(true)
         .allow_external_subcommands(true)
         .subcommand(subcommand);
@@ -33,7 +30,7 @@ fn main() -> CliResult {
         }
     };
 
-    if subcommand_args.is_present("version") {
+    if subcommand_args.flag("version") {
         println!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
