@@ -13,7 +13,6 @@ fn main() -> CliResult {
     let subcommand = subcommand_test("ctest");
 
     let mut app = clap::command!()
-        .setting(AppSettings::DeriveDisplayOrder)
         .dont_collapse_args_in_usage(true)
         .allow_external_subcommands(true)
         .subcommand(subcommand);
@@ -32,7 +31,7 @@ fn main() -> CliResult {
         }
     };
 
-    if subcommand_args.is_present("version") {
+    if subcommand_args.flag("version") {
         println!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
