@@ -79,7 +79,7 @@ fn copy_prebuilt_include_file(
 }
 
 fn build_pc_file(name: &str, root_output: &Path, pc: &PkgConfig) -> anyhow::Result<()> {
-    let pc_path = root_output.join(&format!("{}.pc", name));
+    let pc_path = root_output.join(format!("{name}.pc"));
     let buf = pc.render();
 
     write(pc_path, buf)
@@ -95,7 +95,7 @@ fn build_pc_files(
     build_pc_file(filename, root_output, pc)?;
     let pc_uninstalled = pc.uninstalled(root_output);
     build_pc_file(
-        &format!("{}-uninstalled", filename),
+        &format!("{filename}-uninstalled"),
         root_output,
         &pc_uninstalled,
     )
@@ -147,7 +147,7 @@ fn build_def_file(
             .shell()
             .status("Building", ".def file using dumpbin")?;
 
-        let txt_path = targetdir.join(format!("{}.txt", name));
+        let txt_path = targetdir.join(format!("{name}.txt"));
 
         let target_str = format!("{}-pc-windows-msvc", &target.arch);
         let mut dumpbin = match cc::windows_registry::find(&target_str, "dumpbin.exe") {
@@ -164,7 +164,7 @@ fn build_def_file(
         if out.status.success() {
             let txt_file = open(txt_path)?;
             let buf_reader = BufReader::new(txt_file);
-            let mut def_file = create(targetdir.join(format!("{}.def", name)))?;
+            let mut def_file = create(targetdir.join(format!("{name}.def")))?;
             writeln!(def_file, "EXPORTS")?;
 
             // The Rust loop below is analogue to the following loop.
@@ -190,7 +190,7 @@ fn build_def_file(
                         .to_string()
                 })
             {
-                writeln!(def_file, "\t{}", line)?;
+                writeln!(def_file, "\t{line}")?;
             }
 
             Ok(())
@@ -223,19 +223,20 @@ fn build_implib_file(
             let binutils_arch = match arch.as_str() {
                 "x86_64" => "i386:x86-64",
                 "x86" => "i386",
+                "aarch64" => "arm64",
                 _ => unimplemented!("Windows support for {} is not implemented yet.", arch),
             };
 
             let mut dlltool_command =
                 std::process::Command::new(dlltool.to_str().unwrap_or("dlltool"));
             dlltool_command.arg("-m").arg(binutils_arch);
-            dlltool_command.arg("-D").arg(format!("{}.dll", name));
+            dlltool_command.arg("-D").arg(format!("{name}.dll"));
             dlltool_command
                 .arg("-l")
-                .arg(targetdir.join(format!("{}.dll.a", name)));
+                .arg(targetdir.join(format!("{name}.dll.a")));
             dlltool_command
                 .arg("-d")
-                .arg(targetdir.join(format!("{}.def", name)));
+                .arg(targetdir.join(format!("{name}.def")));
 
             let out = dlltool_command.output()?;
             if out.status.success() {
@@ -257,13 +258,13 @@ fn build_implib_file(
             };
             lib.arg(format!(
                 "/DEF:{}",
-                targetdir.join(format!("{}.def", name)).display()
+                targetdir.join(format!("{name}.def")).display()
             ));
-            lib.arg(format!("/MACHINE:{}", lib_arch));
-            lib.arg(format!("/NAME:{}.dll", name));
+            lib.arg(format!("/MACHINE:{lib_arch}"));
+            lib.arg(format!("/NAME:{name}.dll"));
             lib.arg(format!(
                 "/OUT:{}",
-                targetdir.join(format!("{}.dll.lib", name)).display()
+                targetdir.join(format!("{name}.dll.lib")).display()
             ));
 
             let out = lib.output()?;
@@ -345,7 +346,7 @@ impl FingerPrint {
     }
 
     fn load_previous(&self) -> anyhow::Result<Cache> {
-        let mut f = open(&self.path())?;
+        let mut f = open(self.path())?;
         let mut cache_str = String::new();
         f.read_to_string(&mut cache_str)?;
         let cache = toml::de::from_str(&cache_str)?;
@@ -366,8 +367,8 @@ impl FingerPrint {
                 hash,
                 static_libs: self.static_libs.to_owned(),
             };
-            let buf = toml::ser::to_vec(&cache)?;
-            write(&self.path(), buf)?;
+            let buf = toml::ser::to_string(&cache)?;
+            write(self.path(), buf)?;
         }
 
         Ok(())
@@ -858,8 +859,8 @@ fn set_deps_args(
     }
 }
 
-fn compile_with_exec<'a>(
-    ws: &Workspace<'a>,
+fn compile_with_exec(
+    ws: &Workspace<'_>,
     options: &CompileOptions,
     exec: &Arc<dyn Executor>,
     rustc_target: &target::Target,
@@ -882,7 +883,7 @@ fn compile_with_exec<'a>(
         let mut leaf_args: Vec<String> = rustc_target
             .shared_object_link_args(&capi_config, &install_paths.libdir, root_output)
             .into_iter()
-            .flat_map(|l| vec!["-C".to_string(), format!("link-arg={}", l)])
+            .flat_map(|l| vec!["-C".to_string(), format!("link-arg={l}")])
             .collect();
 
         leaf_args.extend(pkg_rustflags.clone());
@@ -893,7 +894,7 @@ fn compile_with_exec<'a>(
         leaf_args.push("--print".into());
         leaf_args.push("native-static-libs".into());
 
-        if args.is_present("crt-static") {
+        if args.flag("crt-static") {
             leaf_args.push("-C".into());
             leaf_args.push("target-feature=+crt-static".into());
         }
@@ -1007,12 +1008,9 @@ pub fn cbuild(
         _ => vec!["staticlib", "cdylib"],
     };
 
-    let libkinds = if args.is_valid_arg("library-type") {
-        args.values_of("library-type")
-            .map_or_else(default_kind, |v| v.collect::<Vec<_>>())
-    } else {
-        default_kind()
-    };
+    let libkinds = args
+        .get_many::<String>("library-type")
+        .map_or_else(default_kind, |v| v.map(String::as_str).collect::<Vec<_>>());
     let only_staticlib = !libkinds.contains(&"cdylib");
     let only_cdylib = !libkinds.contains(&"staticlib");
 
@@ -1129,8 +1127,11 @@ pub fn cbuild(
                     .unwrap_or_else(|| PathBuf::from("dlltool"));
 
                 // dlltool argument overwrites environment var
-                if args.value_of_os("dlltool").is_some() {
-                    dlltool = args.value_of_os("dlltool").map(PathBuf::from).unwrap();
+                if args.contains_id("dlltool") {
+                    dlltool = args
+                        .get_one::<PathBuf>("dlltool")
+                        .map(PathBuf::from)
+                        .unwrap();
                 }
 
                 build_implib_file(ws, lib_name, &rustc_target, &root_output, &dlltool)?;
@@ -1207,14 +1208,14 @@ pub fn ctest(
     compile_opts.target_rustc_args = None;
 
     let ops = ops::TestOptions {
-        no_run: args.is_present("no-run"),
-        no_fail_fast: args.is_present("no-fail-fast"),
+        no_run: args.flag("no-run"),
+        no_fail_fast: args.flag("no-fail-fast"),
         compile_opts,
     };
 
-    let test_args = args.value_of("TESTNAME").into_iter();
-    let test_args = test_args.chain(args.values_of("args").unwrap_or_default());
-    let test_args = test_args.collect::<Vec<_>>();
+    let test_args = args.get_one::<String>("TESTNAME").into_iter();
+    let test_args = test_args.chain(args.get_many::<String>("args").unwrap_or_default());
+    let test_args = test_args.map(String::as_str).collect::<Vec<_>>();
 
     use std::ffi::OsString;
 
